@@ -7,7 +7,7 @@ from ..consts import get_token, LOGS
 import requests
 
 
-@respond_to('shadok_patrice(.*)')
+@respond_to('shadok (.*)')
 def call_jabberbot_cmd(message, cmd):
     """Cette fonction permet d'appeler les commandes de bot-services"""
     token = get_token()
